<template>
	<el-dialog v-model="dialogVisible" :before-close="resetForm" :fullscreen="full" :title="titles" width="50%" draggable @close="resetForm">
		<el-button @click="toggleFullscreen" size="small" class="pot" :icon="FullScreen"></el-button>
		<el-form :model="form" :disabled="disabled" label-width="120px">
			<el-row>
				<el-col :span="24">
					<el-form-item label="岗位" size="default">
						<el-input v-model="form.jobName" placeholder="请选择">
							<template #append> <el-button :icon="Search" @click="daiInpt" /> </template
						></el-input>
					</el-form-item>
				</el-col>
			</el-row>
			<el-row>
				<el-col :span="24">
					<el-form-item label="责任书签订日期" size="default">
						<el-date-picker v-model="form.signDate" style="width:100%" format="YYYY-MM-DD HH:mm:ss" value-format="YYYY-MM-DD HH:mm:ss" type="datetime" placeholder="请选择日期时间" />
					</el-form-item>
				</el-col>
			</el-row>
			<el-row>
				<el-col :span="24">
					<el-form-item label="备注信息">
						<el-input v-model="form.memo" type="textarea" />
					</el-form-item>
				</el-col>
			</el-row>
			<el-row>
				<el-col :span="24">
					<el-form-item label="责任书附件">
						<uploaderFile :fileList="fileList" :systemName="'GOAL_MANAGE'" :disabled="disabled"
									  @successUploader="successUploader" @deleteFile="deleteFile"></uploaderFile>
					</el-form-item>
				</el-col>
			</el-row>
		</el-form>
		<template #footer>
			<span class="dialog-footer">
				<el-button @click="resetForm" size="default">关闭</el-button>
				<el-button type="primary" @click="submitForm" size="default">确定</el-button>
			</span>
		</template>
	</el-dialog>
	<DailogSearch ref="Shows" @backNum="IdNumber"></DailogSearch>
</template>
<script lang="ts">
import { defineComponent, ref, reactive } from 'vue';
import { Search, FullScreen } from '@element-plus/icons-vue';
import DailogSearch from './DailogSearch.vue';
import { ElMessage, ElMessageBox } from 'element-plus';
import type { UploadProps, UploadUserFile } from 'element-plus';
import { goalManagementApi } from '/@/api/goalManagement';
import uploaderFile from '/@/components/uploaderFile/index.vue';
export default defineComponent({
	components: { DailogSearch,uploaderFile },
	setup(props, { emit }) {
		const dialogVisible = ref<boolean>(false);
		const form = ref({
			indexNum: '', //目标指标编号
			memo: '', ////备注信息
			signDate: '', //责任书签订日期
			extraFile: '', //责任书附件
			jobId: '', //岗位
		});
		const titles = ref();
		const disabled = ref(false);
		// 打开弹窗
		const openDailog = (title: string, value: any, id: number) => {
			dialogVisible.value = true;
			titles.value =`${title}目标责任书`;
			disabled.value = title == '查看' ? true : false;
			if (title == '查看' || title == '修改')
				goalManagementApi()
					.gettargetDutyfileInfoDetail(id)
					.then((res) => {
						if (res.data.code == 200) {
							form.value = res.data.data;
							form.value.signDate=timeC(form.value.signDate)


							if(res.data.data.extraFile!=null&&res.data.data.extraFile!=''){
								var extraFileList = res.data.data.extraFile.split(',')
								for(var a = 0;a<extraFileList.length;a++){
									fileList.value.push(
											{
												name:extraFileList[a]
											}
									)
								}
							}else {
								fileList.value = []
							}
						} else {
							ElMessage.error(res.data.msg);
						}
					});
		};
		// 上传成功组装数据
		const successUploader = (list) =>{
			console.log('successUploader',list)
			fileList.value = list
			var formFileList = ''
			for(var a = 0;a<fileList.value.length;a++){
				if(a==fileList.value.length-1){
					formFileList+=fileList.value[a].name
				}else {
					formFileList+=fileList.value[a].name+','
				}
			}
			form.value.extraFile = formFileList
		}
		const deleteFile = (list) =>{
			console.log('deleteFile',list)
			fileList.value = list
			const formFileList = ''
			for(var a = 0;a<fileList.value.length;a++){
				if(a==fileList.value.length-1){
					formFileList.value+=fileList.value[a].name
				}else {
					formFileList.value+=fileList.value[a].name+','
				}
			}
			form.value.extraFile = formFileList
		}
		const timeC = (timestamp: any) => {
			let a = new Date(timestamp).getTime();
			const date = new Date(a);
			const Y = date.getFullYear() + '-';
			const M = (date.getMonth() + 1 < 10 ? '0' + (date.getMonth() + 1) : date.getMonth() + 1) + '-';
			const D = (date.getDate() < 10 ? '0' + date.getDate() : date.getDate()) + '  ';
			const h = (date.getHours() < 10 ? '0' + date.getHours() : date.getHours()) + ':';
			const m = date.getMinutes() < 10 ? '0' + date.getMinutes() : date.getMinutes();
			const s = date.getSeconds(); // 秒
			const dateString = Y + M + D + h + m +`:${s}`;
			// console.log('dateString', dateString); // > dateString 2021-07-06 14:23
			return dateString;
		};
		// 提交
		const submitForm = () => {
			dialogVisible.value = false;
			delete form.value.jobName
			goalManagementApi()
				.gettargetDutyfileInfoAddorUpdata(form.value)
				.then((res) => {
					if (res.data.code == 200) {
						ElMessage({
							message: res.data.msg,
							type: 'success',
						});
						emit('navAddorUpdata');
					} else {
						ElMessage.error(res.data.msg);
					}
				});
			form.value = {
				indexNum: '', //目标指标编号
				memo: '', ////备注信息
				signDate: '', //责任书签订日期
				extraFile: '666', //责任书附件
				jobId: '', //岗位
			};
		};
		//   取消
		const resetForm = () => {
			dialogVisible.value = false;
			form.value = {
				indexNum: '', //目标指标编号
				memo: '', ////备注信息
				signDate: '', //责任书签订日期
				extraFile: '666', //责任书附件
				jobId: '', //岗位
			};
			fileList.value = []
		};
		// 安全目标指标弹窗
		const Shows = ref();
		const daiInpt = () => {
			Shows.value.openDailog();
		};
		const IdNumber=(val:any)=>{
         form.value.jobId=val.id
		 form.value.jobName=val.date
		}
		// 点击上传
		const fileList = ref([
		]);

		const handleRemove: UploadProps['onRemove'] = (file, uploadFiles) => {
			console.log(file, uploadFiles);
		};

		const handlePreview: UploadProps['onPreview'] = (uploadFile) => {
			console.log(uploadFile);
		};

		const handleExceed: UploadProps['onExceed'] = (files, uploadFiles) => {
			ElMessage.warning(`The limit is 3, you selected ${files.length} files this time, add up to ${files.length + uploadFiles.length} totally`);
		};

		const beforeRemove: UploadProps['beforeRemove'] = (uploadFile, uploadFiles) => {
			return ElMessageBox.confirm(`Cancel the transfert of ${uploadFile.name} ?`).then(
				() => true,
				() => false
			);
		};
		//全屏
		const full = ref(false);
		const toggleFullscreen = () => {
			if (full.value == false) {
				full.value = true;
			} else {
				full.value = false;
			}
		};
		return {
			timeC,
			IdNumber,
			dialogVisible,
			form,
			disabled,
			titles,
			openDailog,
			daiInpt,
			submitForm,
			resetForm,
			Shows,
			Search,
			fileList,
			handleRemove,
			handlePreview,
			handleExceed,
			beforeRemove,
			full,
			toggleFullscreen,
			FullScreen,
			successUploader,
			deleteFile
		};
	},
});
</script>
<style scoped>
.el-row {
	padding: 0 0 20px 0;
}
</style>
